@@ -21,24 +21,19 @@
 #define PLUGINEDITOR_H
 #include <QObject>
 #include "messagecomposer_export.h"
-
-class KActionCollection;
+#include <PimCommon/AbstractGenericPlugin>
 namespace MessageComposer
 {
-class PluginEditorInterface;
 class PluginEditorPrivate;
-class MESSAGECOMPOSER_EXPORT PluginEditor : public QObject
+class MESSAGECOMPOSER_EXPORT PluginEditor : public PimCommon::AbstractGenericPlugin
 {
     Q_OBJECT
 public:
     explicit PluginEditor(QObject *parent = Q_NULLPTR);
     ~PluginEditor();
     void setOrder(int order);
-
-    virtual PluginEditorInterface *createInterface(KActionCollection *ac, QObject *parent = Q_NULLPTR) = 0;
     int order() const;
 
-    virtual QString description() const;
 private:
     PluginEditorPrivate *const d;
 };
