@@ -22,34 +22,11 @@
 
 #include <QObject>
 #include "messagecomposer_export.h"
-namespace KIdentityManagement
-{
-class IdentityManager;
-}
 
 namespace MessageComposer
 {
 class PluginEditorCheckBeforeSendPrivate;
 class PluginEditorCheckBeforeSendInterface;
-class PluginEditorCheckBeforeSendConfigureWidget;
-
-struct MESSAGECOMPOSER_EXPORT PluginEditorCheckBeforeSendConfigureWidgetSetting {
-    PluginEditorCheckBeforeSendConfigureWidgetSetting()
-        : configureWidget(Q_NULLPTR)
-    {
-
-    }
-
-    PluginEditorCheckBeforeSendConfigureWidgetSetting(MessageComposer::PluginEditorCheckBeforeSendConfigureWidget *w, const QString &widgetName)
-        : name(widgetName),
-          configureWidget(w)
-    {
-
-    }
-
-    QString name;
-    MessageComposer::PluginEditorCheckBeforeSendConfigureWidget *configureWidget;
-};
 
 class MESSAGECOMPOSER_EXPORT PluginEditorCheckBeforeSend : public QObject
 {
@@ -60,14 +37,17 @@ public:
 
     virtual PluginEditorCheckBeforeSendInterface *createInterface(QObject *parent) = 0;
 
-    virtual bool hasConfigureSupport() const;
+    virtual bool hasConfigureDialog() const;
 
-    virtual PluginEditorCheckBeforeSendConfigureWidgetSetting createConfigureWidget(KIdentityManagement::IdentityManager *identityManager, QWidget *parent) const;
+    virtual void showConfigureDialog(QWidget *parent = Q_NULLPTR);
 
     void emitConfigChanged();
 
     virtual QString description() const;
 
+    void setIsEnabled(bool enabled);
+    bool isEnabled() const;
+
 Q_SIGNALS:
     void configChanged();
 
