@@ -24,15 +24,9 @@
 #include "messagecomposer_export.h"
 #include "plugineditorcheckbeforesendparams.h"
 
-namespace KIdentityManagement
-{
-class IdentityManager;
-}
-
 namespace MessageComposer
 {
 class PluginEditorCheckBeforeSendInterfacePrivate;
-class PluginEditorCheckBeforeSendConfigureWidget;
 class PluginEditorCheckBeforeSendParams;
 class MESSAGECOMPOSER_EXPORT PluginEditorCheckBeforeSendInterface : public QObject
 {
@@ -46,10 +40,6 @@ public:
     void setParentWidget(QWidget *parent);
     QWidget *parentWidget() const;
 
-    void setIdentityManagement(KIdentityManagement::IdentityManager *identityManagement);
-    KIdentityManagement::IdentityManager *identityManagement() const;
-
-
     void setParameters(const MessageComposer::PluginEditorCheckBeforeSendParams &params);
     MessageComposer::PluginEditorCheckBeforeSendParams parameters() const;
 
