@@ -22,9 +22,11 @@
 #include "webengineviewer/webenginescript.h"
 #include "mailwebenginescript.h"
 #include "messageviewer/messageviewersettings.h"
+#include "../urlhandlermanager.h"
 #include "loadexternalreferencesurlinterceptor/loadexternalreferencesurlinterceptor.h"
+#include "blockexternalresourcesurlinterceptor/blockexternalresourcesurlinterceptor.h"
 #include "cidreferencesurlinterceptor/cidreferencesurlinterceptor.h"
-#include <WebEngineViewer/NetworkAccessManagerWebEngine>
+#include <WebEngineViewer/InterceptorManager>
 #include <WebEngineViewer/WebEngineManageScript>
 
 #include "scamdetection/scamdetectionwebengine.h"
@@ -65,15 +67,21 @@ public:
           mWebViewAccessKey(Q_NULLPTR),
           mExternalReference(Q_NULLPTR),
           mPageEngine(Q_NULLPTR),
-          mNetworkAccessManager(Q_NULLPTR)
+          mNetworkAccessManager(Q_NULLPTR),
+          mViewer(Q_NULLPTR),
+          mCanStartDrag(false)
     {
 
     }
+    QUrl mHoveredUrl;
+    QPoint mLastClickPosition;
     ScamDetectionWebEngine *mScamDetection;
     WebEngineViewer::WebEngineAccessKey *mWebViewAccessKey;
     MessageViewer::LoadExternalReferencesUrlInterceptor *mExternalReference;
     MailWebEnginePage *mPageEngine;
-    WebEngineViewer::NetworkAccessManagerWebEngine *mNetworkAccessManager;
+    WebEngineViewer::InterceptorManager *mNetworkAccessManager;
+    MessageViewer::ViewerPrivate *mViewer;
+    bool mCanStartDrag;
 };
 
 MailWebEngineView::MailWebEngineView(KActionCollection *ac, QWidget *parent)
@@ -90,11 +98,15 @@ MailWebEngineView::MailWebEngineView(KActionCollection *ac, QWidget *parent)
     connect(d->mWebViewAccessKey, &WebEngineViewer::WebEngineAccessKey::openUrl, this, &MailWebEngineView::openUrl);
     connect(this, &MailWebEngineView::loadFinished, this, &MailWebEngineView::slotLoadFinished);
 
-    d->mNetworkAccessManager = new WebEngineViewer::NetworkAccessManagerWebEngine(this, ac, this);
+    d->mNetworkAccessManager = new WebEngineViewer::InterceptorManager(this, ac, this);
     d->mExternalReference = new MessageViewer::LoadExternalReferencesUrlInterceptor(this);
     d->mNetworkAccessManager->addInterceptor(d->mExternalReference);
     MessageViewer::CidReferencesUrlInterceptor *cidReference = new MessageViewer::CidReferencesUrlInterceptor(this);
     d->mNetworkAccessManager->addInterceptor(cidReference);
+    MessageViewer::BlockExternalResourcesUrlInterceptor *blockExternalUrl = new MessageViewer::BlockExternalResourcesUrlInterceptor(this);
+    connect(blockExternalUrl, &BlockExternalResourcesUrlInterceptor::formSubmittedForbidden, this, &MailWebEngineView::formSubmittedForbidden);
+
+    d->mNetworkAccessManager->addInterceptor(blockExternalUrl);
     setFocusPolicy(Qt::WheelFocus);
     connect(d->mPageEngine, &MailWebEnginePage::urlClicked, this, &MailWebEngineView::openUrl);
 #if QT_VERSION >= 0x050700
@@ -108,6 +120,10 @@ MailWebEngineView::~MailWebEngineView()
     delete d;
 }
 
+void MailWebEngineView::setLinkHovered(const QUrl &url)
+{
+    d->mHoveredUrl = url;
+}
 
 void MailWebEngineView::runJavaScriptInWordId(const QString &script)
 {
@@ -118,13 +134,14 @@ void MailWebEngineView::runJavaScriptInWordId(const QString &script)
 #endif
 }
 
+void MailWebEngineView::setViewer(MessageViewer::ViewerPrivate *viewer)
+{
+    d->mViewer = viewer;
+}
+
 void MailWebEngineView::initializeScripts()
 {
     initializeJQueryScript();
-    const QString scripts = MessageViewer::MailWebEngineScript::manageShowHideAttachments() +
-                            MessageViewer::MailWebEngineScript::manageExpandAddresses(QStringLiteral("To")) +
-                            MessageViewer::MailWebEngineScript::manageExpandAddresses(QStringLiteral("Cc"));
-    addScript(scripts, QStringLiteral("emailmanagement"), QWebEngineScript::DocumentReady);
 }
 
 void MailWebEngineView::contextMenuEvent(QContextMenuEvent *e)
@@ -177,20 +194,41 @@ void MailWebEngineView::forwardKeyReleaseEvent(QKeyEvent *e)
 
 void MailWebEngineView::forwardMousePressEvent(QMouseEvent *event)
 {
-    Q_UNUSED(event);
-    //qDebug()<<" void MailWebEngineView::forwardMousePressEvent(QMouseEvent *event)";
+    if (d->mViewer) {
+        if (event->button() == Qt::LeftButton && (event->modifiers() & Qt::ShiftModifier)) {
+            // special processing for shift+click
+            URLHandlerManager::instance()->handleShiftClick(d->mHoveredUrl, d->mViewer);
+            event->accept();
+            return;
+        }
+        if (event->button() == Qt::LeftButton) {
+            d->mCanStartDrag = URLHandlerManager::instance()->willHandleDrag(d->mHoveredUrl, d->mViewer);
+            d->mLastClickPosition = event->pos();
+        }
+    }
 }
 
 void MailWebEngineView::forwardMouseMoveEvent(QMouseEvent *event)
 {
-    Q_UNUSED(event);
-    //qDebug() << "void MailWebEngineView::forwardMouseMoveEvent(QMouseEvent *event)";
+    if (d->mViewer) {
+        // If we are potentially handling a drag, deal with that.
+        if (d->mCanStartDrag && (event->buttons() & Qt::LeftButton)) {
+
+            if ((d->mLastClickPosition - event->pos()).manhattanLength() > QApplication::startDragDistance()) {
+                if (URLHandlerManager::instance()->handleDrag(d->mHoveredUrl, d->mViewer)) {
+                    // If the URL handler manager started a drag, don't handle this in the future
+                    d->mCanStartDrag = false;
+                }
+            }
+            event->accept();
+        }
+    }
 }
 
 void MailWebEngineView::forwardMouseReleaseEvent(QMouseEvent *event)
 {
     Q_UNUSED(event);
-    //qDebug() << "void MailWebEngineView::forwardMouseReleaseEvent(QMouseEvent *event)";
+    d->mCanStartDrag = false;
 }
 
 void MailWebEngineView::forwardKeyPressEvent(QKeyEvent *e)
@@ -316,12 +354,22 @@ void MailWebEngineView::scrollPageUp(int percent)
     scrollPageDown(-percent);
 }
 
-void MailWebEngineView::executeCustomRenderingScripts()
+void MailWebEngineView::executeHideShowToAddressScripts(bool hide)
 {
-    const QString scripts = MessageViewer::MailWebEngineScript::manageShowHideAttachments() +
-                            MessageViewer::MailWebEngineScript::manageExpandAddresses(QStringLiteral("To")) +
-                            MessageViewer::MailWebEngineScript::manageExpandAddresses(QStringLiteral("Cc"));
-    runJavaScriptInWordId(scripts);
+    const QString source = MessageViewer::MailWebEngineScript::manageShowHideToAddress(hide);
+    runJavaScriptInWordId(source);
+}
+
+void MailWebEngineView::executeHideShowCcAddressScripts(bool hide)
+{
+    const QString source = MessageViewer::MailWebEngineScript::manageShowHideCcAddress(hide);
+    runJavaScriptInWordId(source);
+}
+
+void MailWebEngineView::executeHideShowAttachmentsScripts(bool hide)
+{
+    const QString source = MessageViewer::MailWebEngineScript::manageShowHideAttachments(hide);
+    runJavaScriptInWordId(source);
 }
 
 void MailWebEngineView::injectAttachments(const boost::function<QString()> &delayedHtml)
@@ -339,38 +387,14 @@ void MailWebEngineView::toggleFullAddressList(const QString &field, const boost:
     if (html.isEmpty()) {
         return;
     }
-
-    //qDebug() << "void MailWebEngineView::toggleFullAddressList(const QString &field, const boost::function<QString()> &delayedHtml, bool doShow)" << html << " fields " << field;
     runJavaScriptInWordId(MessageViewer::MailWebEngineScript::replaceInnerHtml(field, html));
 }
 
-bool MailWebEngineView::hasVerticalScrollBar() const
-{
-    qDebug() << "bool MailWebEngineView::hasVerticalScrollBar() const not implemented";
-    //TODO
-    return false;
-}
-
-bool MailWebEngineView::isAttachmentInjectionPoint(const QPoint &globalPos) const
-{
-    Q_UNUSED(globalPos);
-    qDebug() << "bool MailWebEngineView::isAttachmentInjectionPoint(const QPoint &globalPos) const not implemented";
-    //TODO
-    return false;
-}
-
 void MailWebEngineView::scrollToRelativePosition(qreal pos)
 {
     runJavaScriptInWordId(WebEngineViewer::WebEngineScript::scrollToRelativePosition(pos));
 }
 
-QUrl MailWebEngineView::linkOrImageUrlAt(const QPoint &global) const
-{
-    Q_UNUSED(global);
-    //TODO
-    return {};
-}
-
 void MailWebEngineView::setAllowExternalContent(bool b)
 {
     if (d->mExternalReference->allowExternalContent() != b) {
@@ -389,22 +413,7 @@ void MailWebEngineView::slotLoadFinished()
     scamCheck();
 }
 
-void MailWebEngineView::dragEnterEvent(QDragEnterEvent *event)
+void MailWebEngineView::setPrintElementBackground(bool printElementBackground)
 {
-    Q_UNUSED(event);
-    qDebug() << " void MailWebEngineView::dragEnterEvent(QDragEnterEvent *event)";
+    d->mPageEngine->setPrintElementBackground(printElementBackground);
 }
-
-void MailWebEngineView::dragMoveEvent(QDragMoveEvent *e)
-{
-    qDebug() << " void MailWebEngineView::dragMoveEvent(QDragMoveEvent *e)";
-    WebEngineViewer::WebEngineView::dragMoveEvent(e);
-    //TODO
-}
-
-void MailWebEngineView::dropEvent(QDropEvent *e)
-{
-    Q_UNUSED(e);
-    qDebug() << " MailWebEngineView::dropEvent";
-}
-
