@@ -25,9 +25,11 @@ class MessageViewer::ViewerPluginPrivate
 {
 public:
     ViewerPluginPrivate()
+        : mEnabled(false)
     {
 
     }
+    bool mEnabled;
 };
 
 ViewerPlugin::ViewerPlugin(QObject *parent)
@@ -42,3 +44,23 @@ ViewerPlugin::~ViewerPlugin()
     delete d;
 }
 
+void ViewerPlugin::showConfigureDialog(QWidget *parent)
+{
+    Q_UNUSED(parent);
+}
+
+bool ViewerPlugin::hasConfigureDialog() const
+{
+    return false;
+}
+
+void ViewerPlugin::setIsEnabled(bool enabled)
+{
+    d->mEnabled = enabled;
+}
+
+bool ViewerPlugin::isEnabled() const
+{
+    return d->mEnabled;
+}
+
