@@ -25,7 +25,7 @@
 #include "viewer/objecttreeparser.h"
 #include "viewer/messagepart.h"
 
-#include <Libkleo/CryptoBackendFactory>
+#include <QGpgME/Protocol>
 
 #include <KMime/Content>
 
@@ -64,7 +64,7 @@ Interface::MessagePart::Ptr ApplicationPkcs7MimeBodyPartFormatter::process(Inter
         return MessagePart::Ptr();
     }
 
-    const Kleo::CryptoBackend::Protocol *smimeCrypto = Kleo::CryptoBackendFactory::instance()->smime();
+    const auto smimeCrypto = QGpgME::smime();
     if (!smimeCrypto) {
         return MessagePart::Ptr();
     }
@@ -98,8 +98,8 @@ Interface::MessagePart::Ptr ApplicationPkcs7MimeBodyPartFormatter::process(Inter
         }
 
         auto _mp = EncryptedMessagePart::Ptr(new EncryptedMessagePart(part.objectTreeParser(),
-                                    node->decodedText(), smimeCrypto,
-                                    NodeHelper::fromAsString(node), node));
+                                             node->decodedText(), smimeCrypto,
+                                             NodeHelper::fromAsString(node), node));
         mp = _mp;
         _mp->setIsEncrypted(true);
         _mp->setDecryptMessage(part.source()->decryptMessage());
@@ -149,8 +149,8 @@ Interface::MessagePart::Ptr ApplicationPkcs7MimeBodyPartFormatter::process(Inter
         const QTextCodec *aCodec(part.objectTreeParser()->codecFor(signTestNode));
         const QByteArray signaturetext = signTestNode->decodedContent();
         auto _mp = SignedMessagePart::Ptr(new SignedMessagePart(part.objectTreeParser(),
-                                    aCodec->toUnicode(signaturetext), smimeCrypto,
-                                    NodeHelper::fromAsString(node), signTestNode));
+                                          aCodec->toUnicode(signaturetext), smimeCrypto,
+                                          NodeHelper::fromAsString(node), signTestNode));
         mp = _mp;
         //mp->setDecryptMessage(part.source()->decryptMessage());
         PartMetaData *messagePart(mp->partMetaData());
